// Rover.java

import ch.aplu.nxt.*;

public class Rover extends NxtRobot
{
  private Motor motorA = new Motor(MotorPort.A);
  private Motor motorB = new Motor(MotorPort.B);
  private LightSensor ls = new LightSensor();
  private static final String btName = "APLU1";
  private final int linearSpeed = 15;
  private final int angularSpeed = 3;

  public Rover()
  {
    super(btName, false);
    addPart(motorA);
    addPart(motorB);
    addPart(ls);
  }

  public boolean bluetoothConnect()
  {
    System.out.println("Connecting via Bluetooth to " + btName + " now...");
    boolean rc = connect(false, true);
    if (rc)
    {
      System.out.println("Bluetooth connection established.");
      ls.activate(true);
    }
    else
      System.out.println("Bluetooth connection failed. (Is Nxt turned on?)");
    return rc;
  }

  public int getIntensity()
  {
    return ls.getValue();
  }

  public void stop()
  {
    System.out.println("Rover stopped");
    motorA.stop();
    motorB.stop();
  }

  public void forward()
  {
    System.out.println("Rover moving forward");
    motorA.setSpeed(linearSpeed);
    motorB.setSpeed(linearSpeed);
    motorA.forward();
    motorB.forward();
  }

  public void backward()
  {
    System.out.println("Rover moving forward");
    motorA.setSpeed(linearSpeed);
    motorB.setSpeed(linearSpeed);
    motorA.backward();
    motorB.backward();
  }

  public void left()
  {
    System.out.println("Rover turning left");
    motorA.setSpeed(angularSpeed);
    motorB.setSpeed(angularSpeed);
    motorA.forward();
    motorB.backward();
  }

  public void right()
  {
    System.out.println("Rover turning right");
    motorA.setSpeed(angularSpeed);
    motorB.setSpeed(angularSpeed);
    motorA.backward();
    motorB.forward();
  }
}
