// Master.java

import ch.aplu.tcp.*;
import ch.aplu.jgamegrid.*;
import java.awt.event.*;
import java.awt.Color;
import javax.swing.JOptionPane;

public class Master extends GameGrid
  implements TcpNodeListener, GGKeyListener
{
  private final String nickname = "NxtMaster";
  private static String sessionID;
  private TcpNode node = new TcpNode();
  private NxtActor actor = new NxtActor();
  private static int vGreen;
  private final int vInterval = 30;

  public Master()
  {
    super(500, 500, 1, null, null, false, 360);
    addStatusBar(30);
    addKeyListener(this);
    setSimulationPeriod(50);
    addActor(actor, new Location(250, 250), -90);
    init();
    show();
    node.addTcpNodeListener(this);
    node.connect(sessionID, nickname);
    doRun();
  }
  
  private void init()
  {
    getBg().clear(Color.white);
    getBg().setPaintColor(Color.black);
    getBg().drawCircle(toPoint(new Location(250, 250)), 150);
    actor.init();
  }

  public void nodeStateChanged(TcpNodeState state)
  {
    if (state == TcpNodeState.CONNECTED)
      setStatusText("Waiting for NxtSlave...");
  }

  public void statusReceived(String text)
  {
    if (text.contains("NxtSlave") && !text.contains("Disconnected"))
    {
      String msg = "NxtSlave connected";
      setStatusText(msg);
    }
    if (text.contains("Disconnected"))
    {
      String msg = "NxtSlave disconnected. Waiting for connection...";
      setStatusText(msg);
    }
  }

  public void messageReceived(String sender, String text)
  {
    int v = Integer.parseInt(text);
    if (Math.abs(v - vGreen) < vInterval)
    {
      getBg().setPaintColor(new Color(0, 150, 170));
      setStatusText("Luminosity = " + v + "; GREEN");
    }
    else
    {
      if (v < vGreen - vInterval)
      {
        getBg().setPaintColor(Color.black);
        setStatusText("Luminosity = " + v + "; BLACK");
      }
      else
      {
        getBg().setPaintColor(Color.white);
        setStatusText("Luminosity = " + v + "; WHITE");
      }
    }
    getBg().fillCircle(toPoint(actor.getSensorLocation()), 8);
  }

  public boolean keyPressed(KeyEvent evt)
  {
    switch (evt.getKeyCode())
    {
      case KeyEvent.VK_SPACE:
        node.sendMessage("0");
        actor.stop();
        break;
      case KeyEvent.VK_UP:
        node.sendMessage("1");
        actor.forward();
        break;
      case KeyEvent.VK_DOWN:
        node.sendMessage("2");
        actor.backward();
        break;
      case KeyEvent.VK_LEFT:
        node.sendMessage("3");
        actor.left();
        break;
      case KeyEvent.VK_RIGHT:
        node.sendMessage("4");
        actor.right();
        break;
      case KeyEvent.VK_R:
        init();
        break;
    }
    return true;
  }

  public boolean keyReleased(KeyEvent evt)
  {
    return true;
  }

  public static void main(String[] args)
  {
    vGreen = 500;
    sessionID = JOptionPane.showInputDialog(null, "SessionID:", "");
    if (sessionID != null)
      new Master();
  }
}
